@@ -106,9 +106,9 @@ def get_job_definition(
     batch_client: boto3.Session = None,
 ) -> dict:
     """
-    Returns a job defintion with the supplied name or empty dict if no matches are found..
+    Returns a job definition with the supplied name or empty dict if no matches are found..
 
-    The returned job defintion will be the most recent, active revision if there are more than one
+    The returned job definition will be the most recent, active revision if there are more than one
     returned from the API.
     """
     if not batch_client:
@@ -416,8 +416,6 @@ def submit_task(
     """
     Submit a redun Task to AWS Batch or Docker (debug=True).
     """
-    module = a_task.func.__module__
-
     if array_size:
         # Output_path will contain a pickled list of actual output paths, etc.
         # Want files that won't get clobbered when jobs actually run
@@ -467,7 +465,7 @@ def submit_task(
             "--check-version",
             aws_utils.REDUN_REQUIRED_VERSION,
             "oneshot",
-            module,
+            a_task.load_module,
         ]
         + import_args
         + code_arg
@@ -784,7 +782,10 @@ def iter_batch_job_logs(
     if not job:
         # Job is no longer present in AWS API. Return no logs.
         return
-    log_stream = job["container"].get("logStreamName", "")
+    log_stream = job["container"].get("logStreamName")
+    if not log_stream:
+        # No log stream is present. Return no logs.
+        return
 
     yield from iter_log_stream(
         log_group_name=log_group_name,
@@ -905,6 +906,7 @@ class AWSBatchExecutor(Executor):
         else:
             self.interval = config.getfloat("job_monitor_interval", 0.2)
 
+        self._thread: Optional[threading.Thread] = None
         self.arrayer = JobArrayer(
             executor=self,
             submit_interval=self.interval,
@@ -980,6 +982,14 @@ class AWSBatchExecutor(Executor):
         self.arrayer.stop()
         self.is_running = False
 
+        # Stop monitor thread.
+        if (
+            self._thread
+            and self._thread.is_alive()
+            and threading.get_ident() != self._thread.ident
+        ):
+            self._thread.join()
+
     def _monitor(self) -> None:
         """
         Thread for monitoring running AWS Batch jobs.
@@ -1159,7 +1169,7 @@ class AWSBatchExecutor(Executor):
                 redun_job, error, error_traceback=error_traceback, job_tags=job_tags
             )
 
-    def _get_task_options(self, job: Job) -> dict:
+    def _get_job_options(self, job: Job) -> dict:
         """
         Determine the task options for a job.
 
@@ -1252,7 +1262,7 @@ class AWSBatchExecutor(Executor):
         job_type = "AWS Batch job" if not self.debug else "Docker container"
 
         # Determine job options.
-        task_options = self._get_task_options(job)
+        task_options = self._get_job_options(job)
         use_cache = task_options.get("cache", True)
 
         # Determine if we can reunite with a previous Batch output or job.
@@ -1302,7 +1312,7 @@ class AWSBatchExecutor(Executor):
         if job.task.script:
             raise NotImplementedError("Array jobs not supported for scripts")
 
-        task_options = self._get_task_options(job)
+        task_options = self._get_job_options(job)
         image = task_options.pop("image", self.image)
         queue = task_options.pop("queue", self.queue)
         # Generate a unique name for job with no '-' to simplify job name parsing.
@@ -1401,7 +1411,7 @@ class AWSBatchExecutor(Executor):
         of an array job
         """
         assert job.task
-        task_options = self._get_task_options(job)
+        task_options = self._get_job_options(job)
         image = task_options.pop("image", self.image)
         queue = task_options.pop("queue", self.queue)
 
