@@ -43,10 +43,10 @@ def register_filesystem(cls: Type["FileSystem"]) -> Type["FileSystem"]:
 
 def get_proto(url: str) -> str:
     """
-    Returns the protocal for a url.
+    Returns the protocol for a url.
 
-    For example the protocal for 'http://example.com' is 'http'. Local paths
-    '/path/to/my/file' have the protocal 'local'.
+    For example the protocol for 'http://example.com' is 'http'. Local paths
+    '/path/to/my/file' have the protocol 'local'.
     """
     return urlparse(url).scheme or "local"
 
@@ -55,7 +55,7 @@ def get_filesystem_class(
     proto: Optional[str] = None, url: Optional[str] = None
 ) -> Type["FileSystem"]:
     """
-    Returns the corresponding FileSystem class for a given url or protocal.
+    Returns the corresponding FileSystem class for a given url or protocol.
     """
     if not proto:
         assert url, "Must give url or proto as argument."
@@ -76,7 +76,7 @@ _filesystem_instances: Dict[Type, "FileSystem"] = {}
 
 def get_filesystem(proto: Optional[str] = None, url: Optional[str] = None) -> "FileSystem":
     """
-    Returns the corresponding FileSystem for a given url or protocal.
+    Returns the corresponding FileSystem for a given url or protocol.
     """
     filesystem_class = get_filesystem_class(proto=proto, url=url)
     filesystem = _filesystem_instances.get(filesystem_class)
@@ -457,7 +457,7 @@ class S3FileSystem(FileSystem):
         try:
             self.s3.rm(path)
         except FileNotFoundError:
-            # It it not an error to try to remove a non-existant File.
+            # It it not an error to try to remove a non-existent File.
             pass
 
     def open(self, path: str, mode: str) -> IO:
@@ -781,23 +781,18 @@ class ShardedS3Dataset(Value):
         self.format = format
 
         self.filesystem: FileSystem = get_filesystem(url=self.path)
-        assert isinstance(self.filesystem, S3FileSystem)
-        self.s3 = self.filesystem.s3
-
-        if self.filesystem.name != "s3":
-            raise ValueError("ShardedS3Dataset requires a path on S3")
-
         self._filenames: List[str] = self._gather_files()
 
     def _gather_files(self) -> List[str]:
-        # All files in current directory.
-        files = glob_file(f"{self.path}/*.{self.format}")
 
         # If recursing, look in subdirectories too.
+        files = glob_file(f"{self.path}/*.{self.format}")
         if self.recurse:
             files.extend(glob_file(f"{self.path}/**/*.{self.format}"))
 
-        return sorted(files)
+        # Work around differences between fsspec's interpretation of ** on S3 vs.local
+        # by removing any duplicate file names from the list.
+        return sorted(set(files))
 
     def update_hash(self) -> None:
         self._hash = self._calc_hash()
@@ -879,6 +874,10 @@ class ShardedS3Dataset(Value):
         # Do this first so if we're not in a Spark env it raises ValueError.
         context = glue.get_glue_context()
 
+        # Only loading from S3 is supported
+        if self.filesystem.name != "s3":
+            raise ValueError("load_spark requires a path on S3")
+
         # Set default options for csv as having a header line.
         f_options = {}
         if self.format == "csv":
@@ -974,7 +973,7 @@ class ShardedS3Dataset(Value):
         self,
         dataset: Union["pandas.DataFrame", "pyspark.sql.DataFrame"],
         partition_keys: List[str] = [],
-        catalog_database: str = "cheminfo",
+        catalog_database: str = "default",
         catalog_table: Optional[str] = None,
         format_options: Dict[str, Any] = {},
     ) -> None:
@@ -995,7 +994,7 @@ class ShardedS3Dataset(Value):
 
         catalog_database : str
             Datacatalog name to write to, if creating a table in the Data Catalog.
-            Defaults to 'cheminfo'
+            Defaults to 'default'
 
         catalog_table : Optional[str]
             If present, written data will be available in AWS Data Catalog / Glue / Athena
@@ -1008,6 +1007,10 @@ class ShardedS3Dataset(Value):
         # Do this first so if we're not in a Spark env it raises ValueError.
         context = glue.get_glue_context()
 
+        # Only saving to S3 is supported
+        if self.filesystem.name != "s3":
+            raise ValueError("save_spark requires a path on S3")
+
         import pandas
         import pyspark
         from awsglue.dynamicframe import DynamicFrame
@@ -1064,6 +1067,62 @@ class ShardedS3Dataset(Value):
         context.purge_s3_path(self.path, options=options)
         self.update_hash()
 
+    @classmethod
+    def from_data(
+        cls,
+        dataset: Union["pandas.DataFrame", "pyspark.sql.DataFrame"],
+        output_path: str,
+        format: str = "parquet",
+        partition_keys: List[str] = [],
+        catalog_database: str = "default",
+        catalog_table: Optional[str] = None,
+        format_options: Dict[str, Any] = {},
+    ):
+        """
+        Helper function to create a ShardedS3Dataset from an existing DataFrame-like object.
+
+        Parameters
+        ----------
+        dataset : Union[pandas.DataFrame, pyspark.sql.DataFrame]
+            Dataset to save
+
+        output_path : str
+            Path on S3 to which data will be saved as multiple files of format `format`.
+
+        format : str
+            Format to save the data in. Supported formats are:
+            `["avro", "csv", "ion", "grokLog", "json", "orc", "parquet", "xml"]`
+            Defaults to parquet.
+
+        partition_keys : List[str]
+            Dataset keys to partition on. Each key will be a subdirectory in
+            `self.path` containing data for each value of that key. For
+            example, partition on the column 'K', will make subdirectores
+            'K=1', 'K=2', 'K=3', etc.
+
+        catalog_database : str
+            Datacatalog name to write to, if creating a table in the Data Catalog.
+            Defaults to 'default'
+
+        catalog_table : Optional[str]
+            If present, written data will be available in AWS Data Catalog / Glue / Athena
+            with the indicated table name.
+
+        format_options : Dict[str, Any]
+            Additional options for the data loader. Documented here:
+            https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-format.html
+        """
+        result = ShardedS3Dataset(output_path, format, recurse=False)
+
+        result.save_spark(
+            dataset,
+            partition_keys=partition_keys,
+            catalog_database=catalog_database,
+            catalog_table=catalog_table,
+            format_options=format_options,
+        )
+        return result
+
 
 T = TypeVar("T")
 
