@@ -8,9 +8,10 @@ from unittest.mock import Mock, patch
 import boto3
 import pytest
 from freezegun import freeze_time
-from moto import mock_logs, mock_s3
+from moto import mock_logs
 
 import redun.executors.aws_batch
+import redun.tests.utils
 from redun import File, job_array, task
 from redun.cli import RedunClient, import_script
 from redun.config import Config
@@ -44,7 +45,7 @@ from redun.executors.aws_utils import (
 from redun.file import Dir
 from redun.scheduler import Execution, Job, Scheduler, Traceback
 from redun.scripting import ScriptError
-from redun.tests.utils import mock_scheduler, use_tempdir, wait_until
+from redun.tests.utils import mock_s3, mock_scheduler, use_tempdir, wait_until
 from redun.utils import pickle_dumps
 
 
@@ -141,7 +142,7 @@ def test_batch_tags(scheduler: Scheduler) -> None:
     job = Job(task1(10), execution=exec1)
     job.task = task1
 
-    batch_tags = executor._get_task_options(job)["batch_tags"]
+    batch_tags = executor._get_job_options(job)["batch_tags"]
     assert batch_tags == {
         "redun_aws_user": "alice",
         "redun_execution_id": "123",
@@ -180,7 +181,7 @@ def test_batch_tags_no_default(scheduler: Scheduler) -> None:
     job = Job(task1(10), execution=exec1)
     job.task = task1
 
-    batch_tags = executor._get_task_options(job)["batch_tags"]
+    batch_tags = executor._get_job_options(job)["batch_tags"]
     assert batch_tags == {
         "step": "final",
         "project": "acme",
@@ -217,10 +218,22 @@ def task1(x):
     return x + 10
 
 
+@task(load_module="custom.module")
+def task1_custom_module(x):
+    return x + 10
+
+
 @use_tempdir
 @mock_s3
 @patch("redun.executors.aws_batch.batch_submit")
-def test_submit_task(batch_submit_mock):
+@pytest.mark.parametrize(
+    "custom_module, expected_load_module, a_task",
+    [
+        (None, "redun.tests.test_aws_batch", task1),
+        ("custom.module", "custom.module", task1_custom_module),
+    ],
+)
+def test_submit_task(batch_submit_mock, custom_module, expected_load_module, a_task):
     job_id = "123"
     image = "my-image"
     queue = "queue"
@@ -233,14 +246,14 @@ def test_submit_task(batch_submit_mock):
 
     # Create example workflow script to be packaged.
     File("workflow.py").write(
-        """
-@task()
+        f"""
+@task(load_module={custom_module})
 def task1(x):
     return x + 10
     """
     )
 
-    job = Job(task1())
+    job = Job(a_task())
     job.id = job_id
     job.eval_hash = "eval_hash"
     code_file = package_code(s3_scratch_prefix)
@@ -249,7 +262,7 @@ def task1(x):
         queue,
         s3_scratch_prefix,
         job,
-        task1,
+        a_task,
         args=[10],
         kwargs={},
         code_file=code_file,
@@ -269,7 +282,7 @@ def task1(x):
             "--check-version",
             REDUN_REQUIRED_VERSION,
             "oneshot",
-            "redun.tests.test_aws_batch",
+            expected_load_module,
             "--code",
             code_file.path,
             "--input",
@@ -278,7 +291,7 @@ def task1(x):
             "s3://example-bucket/redun/jobs/eval_hash/output",
             "--error",
             "s3://example-bucket/redun/jobs/eval_hash/error",
-            "task1",
+            a_task.name,
         ],
         "queue",
         image="my-image",
@@ -527,6 +540,10 @@ def test_iter_batch_job_logs(aws_describe_jobs_mock) -> None:
     with pytest.raises(Exception):
         list(iter_batch_job_logs(job_id, required=True))
 
+    # Fetch logs from job with no logs at all.
+    aws_describe_jobs_mock.side_effect = lambda *args, **kwargs: iter([{"container": {}}])
+    assert list(iter_batch_job_logs(job_id, required=False)) == []
+
 
 def mock_executor(scheduler, debug=False, code_package=False):
     """
@@ -895,7 +912,6 @@ def test_executor_multiple_start(
     executor._start()
     executor._start()
     executor.stop()
-    executor._thread.join()
 
 
 @mock_s3
@@ -933,7 +949,6 @@ def test_interactive(run_docker_mock, iter_local_job_status_mock, get_aws_user_m
 
     # Cleanly stop executor.
     executor.stop()
-    executor._thread.join()
 
 
 @mock_s3
@@ -1391,8 +1406,9 @@ def test_arrayer_thread():
 
 @mock_s3
 @patch("redun.executors.aws_utils.get_aws_user", return_value="alice")
+@patch("redun.executors.aws_batch.aws_describe_jobs")
 @patch("redun.executors.aws_batch.submit_task")
-def test_jobs_are_arrayed(submit_task_mock, get_aws_user_mock):
+def test_jobs_are_arrayed(submit_task_mock, aws_describe_jobs_mock, get_aws_user_mock):
     """
     Tests repeated jobs are submitted as a single array job. Checks that
     job ID for the array job and child jobs end up tracked
@@ -1402,6 +1418,7 @@ def test_jobs_are_arrayed(submit_task_mock, get_aws_user_mock):
     executor.arrayer.min_array_size = 3
     executor.arrayer.max_array_size = 7
 
+    aws_describe_jobs_mock.return_value = iter([])
     redun.executors.aws_batch.submit_task.side_effect = [
         {"jobId": "first-array-job", "arrayProperties": {"size": 7}},
         {"jobId": "second-array-job", "arrayProperties": {"size": 3}},
@@ -1451,6 +1468,7 @@ def test_jobs_are_arrayed(submit_task_mock, get_aws_user_mock):
     executor.stop()
 
 
+@use_tempdir
 @mock_s3
 @patch("redun.executors.aws_utils.get_aws_user", return_value="alice")
 @patch("redun.executors.aws_batch.AWSBatchExecutor._submit_single_job")
