@@ -532,7 +532,7 @@ def test_higher_order2(scheduler: Scheduler) -> None:
     assert scheduler.run(workflow()) == 65
     assert task_calls == ["chooser", "adder"]
 
-    # Changing a child of multipler, changes multipler. Caching should detect this.
+    # Changing a child of multiplier, changes multiplier. Caching should detect this.
     @task()  # type: ignore # noqa: F811
     def get_offset():
         task_calls.append("get_offset")
@@ -1336,17 +1336,15 @@ def test_catch_deep_recover_react(scheduler: Scheduler) -> None:
     assert calls == ["faulty", "recover", "deep", "deep2"]
 
 
-def test_config_arg(scheduler: Scheduler) -> None:
+def test_config_args(scheduler: Scheduler) -> None:
     """
-    Argument types wrapped in ConfigArg should be detectable.
+    Config_args should not contribute to the eval_hash.
     """
 
     @task(config_args=["x", "z"])
     def task1(x: int, y: int, z: str = "hello") -> int:
         return x
 
-    assert scheduler.run(task1(10, 11)) == 10
-
     eval_hash1, args_hash1 = scheduler.get_eval_hash(task1, (10, 11), {})
     # Changing 'x' and 'z' does not change args_hash.
     eval_hash2, args_hash2 = scheduler.get_eval_hash(task1, (11, 11), {"z": "bye"})
@@ -1354,6 +1352,21 @@ def test_config_arg(scheduler: Scheduler) -> None:
     assert args_hash1 == args_hash2
 
 
+def test_variadic_args(scheduler: Scheduler) -> None:
+    """
+    Variadic arguments should contribute to the eval_hash.
+    """
+
+    @task
+    def task1(x: int, y: int, *rest: int) -> int:
+        return x
+
+    eval_hash1, args_hash1 = scheduler.get_eval_hash(task1, (10, 11, 12), {})
+    eval_hash2, args_hash2 = scheduler.get_eval_hash(task1, (10, 11, 12, 13, 14), {})
+    assert eval_hash1 != eval_hash2
+    assert args_hash1 != args_hash2
+
+
 def test_default_root(scheduler: Scheduler, session: Session) -> None:
     """
     We should always have one root job for an Execution.
@@ -1389,3 +1402,27 @@ def test_no_default_root(scheduler: Scheduler, session: Session) -> None:
 
     # We should have the default root task.
     assert exec1.job.task.name == "task1"
+
+
+def test_default_args_expression(scheduler: Scheduler) -> None:
+    """
+    Task default arguments should support expressions.
+    """
+
+    @task
+    def add(a: int, b: int) -> int:
+        return a + b
+
+    @task
+    def main(x: int = add(1, 2)) -> int:
+        return x
+
+    assert scheduler.run(main()) == 3
+    assert scheduler.run(main(4)) == 4
+
+    @task
+    def main2(x: List[int] = [add(1, 2)]) -> List[int]:
+        # Default argument might contain an expression within a nested value (e.g. list).
+        return x
+
+    assert scheduler.run(main2()) == [3]
